package com.ruoyi.project.ticket.service;

import java.util.List;
import com.ruoyi.project.ticket.domain.TTicketId;

/**
 * 作业票编号Service接口
 * 
 * @author ruoyi
 * @date 2022-01-10
 */
public interface ITTicketIdService 
{
    /**
     * 查询作业票编号
     * 
     * @param id 作业票编号ID
     * @return 作业票编号
     */
    public TTicketId selectTTicketIdById(Long id);

    /**
     * 查询作业票编号列表
     * 
     * @param tTicketId 作业票编号
     * @return 作业票编号集合
     */
    public List<TTicketId> selectTTicketIdList(TTicketId tTicketId);

    /**
     * 新增作业票编号
     * 
     * @param tTicketId 作业票编号
     * @return 结果
     */
    public int insertTTicketId(TTicketId tTicketId);

    /**
     * 修改作业票编号
     * 
     * @param tTicketId 作业票编号
     * @return 结果
     */
    public int updateTTicketId(TTicketId tTicketId);

    /**
     * 批量删除作业票编号
     * 
     * @param ids 需要删除的作业票编号ID
     * @return 结果
     */
    public int deleteTTicketIdByIds(Long[] ids);

    /**
     * 删除作业票编号信息
     * 
     * @param id 作业票编号ID
     * @return 结果
     */
    public int deleteTTicketIdById(Long id);
}
